==> nethome-0.0.1.tgz: package/lib/ui/command/AbstSubCommand.js <==
//module nethome.ui.command
/**
 * UI要素をもたないコントローラ
 * @author kawae
**/
export class AbstSubCommand {
    /**
     * コンストラクタ
     * @author kawae
     * @since 2004/01/01
    **/
    constructor() {
    }
    ///**
    // * ターゲットのセット
    // * @param o	ターゲット汎用オブジェクト
    // * @param mode	モード汎用フラグ
    // * @param editmode	編集汎用フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#setTarget(java.lang.Object,java.lang.Object,short,short)
    //**/
    //setTarget(o: Object, mode: number, editmode: number): void {
    //    mMouseMode = mode;
    //    mEditMode = editmode;
    //}
    /**
     * ターゲットのセット
     * @param o1	ターゲット１汎用オブジェクト
     * @param o2	ターゲット２汎用オブジェクト
     * @param mode	モード汎用フラグ
     * @param editmode	編集汎用フラグ
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#setTarget(java.lang.Object,java.lang.Object,short,short)
    **/
    setTarget(o1, o2, mode, editmode) {
        this.mMouseMode = mode;
        this.mEditMode = editmode;
    }
    //getActiveCanvas(): Canvas2D;
    /**
     * コマンド初期化処理
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.Command#play()
    **/
    play() {
    }
    /**
     * コマンド終了処理
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#play()
    **/
    end() {
    }
    ///**
    // * マウス移動処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mouseMove(int,int,int)
    //**/
    //mouseMove(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスボタンプレス処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mousePress(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスドラッグ処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mouseDrag(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスボタンリリース処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mouseRelease(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * キープレス処理
    // * @param i	キーコード
    // * @param m	修飾子
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#keyPress(int,int)
    //**/
    //keyPress(i: number, m: number): boolean {
    //    return false;
    //}
    /**
     * コマンドの描画
     * @param rg	描画コンテキスト
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#drawCommand(jp.kitec.kwt.IRichGraphics)
    **/
    drawCommand(d) {
    }
}
AbstSubCommand.MOUSE_MOVE = 0;
AbstSubCommand.MOUSE_DRAG = 1;
AbstSubCommand.EDIT_NEW = 0;
AbstSubCommand.EDIT_EDIT = 1;
//# sourceMappingURL=AbstSubCommand.js.map

==> nethome-0.1.0.tgz: package/lib/ui/command/AbstSubCommand.js <==
//module nethome.ui.command
/**
 * UI要素をもたないコントローラ
 * @author kawae
**/
var AbstSubCommand = (function () {
    /**
     * コンストラクタ
     * @author kawae
     * @since 2004/01/01
    **/
    function AbstSubCommand() {
    }
    ///**
    // * ターゲットのセット
    // * @param o	ターゲット汎用オブジェクト
    // * @param mode	モード汎用フラグ
    // * @param editmode	編集汎用フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#setTarget(java.lang.Object,java.lang.Object,short,short)
    //**/
    //setTarget(o: Object, mode: number, editmode: number): void {
    //    mMouseMode = mode;
    //    mEditMode = editmode;
    //}
    /**
     * ターゲットのセット
     * @param o1	ターゲット１汎用オブジェクト
     * @param o2	ターゲット２汎用オブジェクト
     * @param mode	モード汎用フラグ
     * @param editmode	編集汎用フラグ
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#setTarget(java.lang.Object,java.lang.Object,short,short)
    **/
    AbstSubCommand.prototype.setTarget = function (o1, o2, mode, editmode) {
        this.mMouseMode = mode;
        this.mEditMode = editmode;
    };
    //getActiveCanvas(): Canvas2D;
    /**
     * コマンド初期化処理
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.Command#play()
    **/
    AbstSubCommand.prototype.play = function () {
    };
    /**
     * コマンド終了処理
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#play()
    **/
    AbstSubCommand.prototype.end = function () {
    };
    ///**
    // * マウス移動処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mouseMove(int,int,int)
    //**/
    //mouseMove(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスボタンプレス処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mousePress(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスドラッグ処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mouseDrag(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * マウスボタンリリース処理
    // * @param x	デバイス上のX座標
    // * @param y	デバイス上のY座標
    // * @param mod	修飾子フラグ
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#mousePress(int,int,int)
    //**/
    //mouseRelease(x: number, y: number, mod: number): boolean {
    //    return false;
    //}
    ///**
    // * キープレス処理
    // * @param i	キーコード
    // * @param m	修飾子
    // * @author kawae
    // * @since 2003/01/01
    // * @see nethome.ui.command.SubCommand#keyPress(int,int)
    //**/
    //keyPress(i: number, m: number): boolean {
    //    return false;
    //}
    /**
     * コマンドの描画
     * @param rg	描画コンテキスト
     * @author kawae
     * @since 2003/01/01
     * @see nethome.ui.command.SubCommand#drawCommand(jp.kitec.kwt.IRichGraphics)
    **/
    AbstSubCommand.prototype.drawCommand = function (d) {
    };
    AbstSubCommand.MOUSE_MOVE = 0;
    AbstSubCommand.MOUSE_DRAG = 1;
    AbstSubCommand.EDIT_NEW = 0;
    AbstSubCommand.EDIT_EDIT = 1;
    return AbstSubCommand;
})();
exports.AbstSubCommand = AbstSubCommand;
//# sourceMappingURL=AbstSubCommand.js.map
